Linear Algebra
===============

Linear algebra is fundamental to arguably most of scientific computation. ProbNum defines (finite-dimensional) linear
operators in a memory-efficient manner and implements probabilistic numerical methods to solve linear systems.

See the notebooks below to learn more about linear algebra in ProbNum.

.. nbgallery::
   :maxdepth: 2

   linalg/linear_operators
   linalg/linear_systems
   linalg/galerkin_method


----

You can also interactively try out the |Tutorials| directly in the browser or
by downloading the notebooks from the
`GitHub repository <https://github.com/probabilistic-numerics/probnum/tree/master/docs/source/tutorials>`_.

.. |Tutorials| image:: https://img.shields.io/badge/Tutorials-Jupyter-579ACA.svg?&logo=Jupyter&logoColor=white
    :target: https://mybinder.org/v2/gh/probabilistic-numerics/probnum/master?filepath=docs%2Fsource%2Ftutorials
    :alt: ProbNum's Tutorials
